pub struct TableKeyConfig {
pub table: String,
pub key_columns: Vec<String>,
}Expand description
Table key configuration for MySQL sources and bootstrappers.
Maps a table name to the columns that form its primary key, used to generate deterministic element IDs.
Fields
table: Stringkey_columns: Vec<String>Trait Implementations
Sourceimpl Clone for TableKeyConfig
impl Clone for TableKeyConfig
Sourcefn clone(&self) -> TableKeyConfig
fn clone(&self) -> TableKeyConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TableKeyConfig
impl Debug for TableKeyConfig
Sourceimpl PartialEq for TableKeyConfig
impl PartialEq for TableKeyConfig
Sourcefn eq(&self, other: &TableKeyConfig) -> bool
fn eq(&self, other: &TableKeyConfig) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for TableKeyConfig